==> imp-doc-2.0.1.tar.gz: html/scores2D_8h.js <==
var scores2D_8h =
[
    [ "ChiSquaredScore", "classIMP_1_1em2d_1_1ChiSquaredScore.html", "classIMP_1_1em2d_1_1ChiSquaredScore" ],
    [ "EM2DScore", "classIMP_1_1em2d_1_1EM2DScore.html", "classIMP_1_1em2d_1_1EM2DScore" ],
    [ "HasHigherCCC", "classIMP_1_1em2d_1_1HasHigherCCC.html", "classIMP_1_1em2d_1_1HasHigherCCC" ],
    [ "HasLowerScore", "classIMP_1_1em2d_1_1HasLowerScore.html", "classIMP_1_1em2d_1_1HasLowerScore" ],
    [ "LessPairBySecond", "classIMP_1_1em2d_1_1LessPairBySecond.html", "classIMP_1_1em2d_1_1LessPairBySecond" ],
    [ "ScoreFunction", "classIMP_1_1em2d_1_1ScoreFunction.html", "classIMP_1_1em2d_1_1ScoreFunction" ],
    [ "ChiSquaredScores", "scores2D_8h.html#a5b8ff3a60997ddbdb47ac3b8fb7afda2", null ],
    [ "EM2DScores", "scores2D_8h.html#aa02fe1f289665a57a8d691f5006f23c1", null ],
    [ "MeanAbsoluteDifferences", "scores2D_8h.html#a7329e907366cbe699503e43b479e060c", null ],
    [ "ScoreFunctions", "scores2D_8h.html#af27ca8d587434ae80d5d574bad55ca42", null ],
    [ "get_average_rotation_error", "scores2D_8h.html#a8827086222efc622180b57244b37c2d4", null ],
    [ "get_average_shift_error", "scores2D_8h.html#a6aa15e3e01020f7803fd8a86f12935cf", null ],
    [ "get_cross_correlation_coefficient", "scores2D_8h.html#a36ce0f68b0bb199a5c0e0e32ded802a6", null ],
    [ "get_global_score", "scores2D_8h.html#a44fe26f303260f075ccda58b350fe8a0", null ],
    [ "get_rotation_error", "scores2D_8h.html#a57a725bb5e94995d20b75abe96d9cfbd", null ],
    [ "get_shift_error", "scores2D_8h.html#ad612906ea96b2c6f162c97b654309c7f", null ]
];

==> imp-doc-2.1.1.tar.gz: html/scores2D_8h.js <==
var scores2D_8h =
[
    [ "ChiSquaredScore", "classIMP_1_1em2d_1_1ChiSquaredScore.html", "classIMP_1_1em2d_1_1ChiSquaredScore" ],
    [ "EM2DScore", "classIMP_1_1em2d_1_1EM2DScore.html", "classIMP_1_1em2d_1_1EM2DScore" ],
    [ "HasHigherCCC", "classIMP_1_1em2d_1_1HasHigherCCC.html", "classIMP_1_1em2d_1_1HasHigherCCC" ],
    [ "HasLowerScore", "classIMP_1_1em2d_1_1HasLowerScore.html", "classIMP_1_1em2d_1_1HasLowerScore" ],
    [ "LessPairBySecond", "classIMP_1_1em2d_1_1LessPairBySecond.html", "classIMP_1_1em2d_1_1LessPairBySecond" ],
    [ "MeanAbsoluteDifference", "classIMP_1_1em2d_1_1MeanAbsoluteDifference.html", "classIMP_1_1em2d_1_1MeanAbsoluteDifference" ],
    [ "ScoreFunction", "classIMP_1_1em2d_1_1ScoreFunction.html", "classIMP_1_1em2d_1_1ScoreFunction" ],
    [ "ChiSquaredScores", "scores2D_8h.html#a5b8ff3a60997ddbdb47ac3b8fb7afda2", null ],
    [ "ChiSquaredScoresTemp", "scores2D_8h.html#a2debbec9a1cb5c04f498d31311f570ef", null ],
    [ "EM2DScores", "scores2D_8h.html#aa02fe1f289665a57a8d691f5006f23c1", null ],
    [ "EM2DScoresTemp", "scores2D_8h.html#a119a19c90f9203ad6a923a710146dd6d", null ],
    [ "MeanAbsoluteDifferences", "scores2D_8h.html#a7329e907366cbe699503e43b479e060c", null ],
    [ "MeanAbsoluteDifferencesTemp", "scores2D_8h.html#abbe0c5807a2007f836c84c87b18b0737", null ],
    [ "ScoreFunctions", "scores2D_8h.html#af27ca8d587434ae80d5d574bad55ca42", null ],
    [ "ScoreFunctionsTemp", "scores2D_8h.html#af8132659abe83c8fa62be49ad1544e48", null ],
    [ "get_average_rotation_error", "scores2D_8h.html#a8827086222efc622180b57244b37c2d4", null ],
    [ "get_average_shift_error", "scores2D_8h.html#a6aa15e3e01020f7803fd8a86f12935cf", null ],
    [ "get_cross_correlation_coefficient", "scores2D_8h.html#a36ce0f68b0bb199a5c0e0e32ded802a6", null ],
    [ "get_global_score", "scores2D_8h.html#a44fe26f303260f075ccda58b350fe8a0", null ],
    [ "get_rotation_error", "scores2D_8h.html#a57a725bb5e94995d20b75abe96d9cfbd", null ],
    [ "get_shift_error", "scores2D_8h.html#ad612906ea96b2c6f162c97b654309c7f", null ]
];
